<?php
$page_title = "ユーザー一覧";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href=""><img src="img/logo.png" alt="iWallet"></a></h1>
				<div class="aside-heading">
					<div class="btns">
						<input type="button" id="btnSearchAll" name="btnSearchAll" value="すべて" class="btn bg-default px50 hi22">&nbsp;
						<input type="button" id="btnSearchToday" name="btnSearchToday" value="本日" class="btn bg-default px50 hi22">&nbsp;
						<input type="button" id="btnSearch" value="検索" class="btn bg-default px50 hi22">
						<input type="button" id="btnBalacne" value="全ユーザーの残高" class="btn bg-default px110 hi22">
						<form id="downloadForm" action="https://secure.<?php echo SITE_DOMAIN; ?>/api/GetBalanceAllUser" method="post"></form>
					</div>
				</div>
				<form id="searchForm" action="" method="post">
					<table class="conditions fontS w100p">
						<colgroup>
							<col class="w40p">
							<col class="w60p">
						</colgroup>
						<tr>
							<th>所属WL</th>
							<td>
								<select id="wl_id" name="wl_id" class="w100p">
									<option value="">--- すべて ---</option>
									<?php $this -> dispWLId(); ?>
								</select>
							</td>
						</tr>
						<tr>
							<th>メールアドレス</th>
							<td><input type="text" id="email" name="email" value="<?php $this -> echoMail(); ?>" class="w100p"></td>
						</tr>
						<tr>
							<th>名前</th>
							<td><input type="text" id="name" name="name" value="<?php $this -> echoName(); ?>" class="w100p"></td>
						</tr>
						<tr>
							<th>口座種別</th>
							<td>
								<select id="account_type" name="account_type" class="w100p">
									<option value="">--- すべて ---</option>
									<?php $this -> echoAccountType(); ?>
								</select>
							</td>
						</tr>
						<tr>
							<th>口座カテゴリー</th>
							<td>
								<select id="test_account_flg" name="test_account_flg" class="w100p">
									<option value="">--- すべて ---</option>
									<?php $this -> echoTestAccountFlg(); ?>
							</td>
						</tr>
						<tr>
							<th>口座番号</th>
							<td><input type="text" id="user_account" name="user_account" value="<?php $this -> echoAccountNumber(); ?>" class="w100p"></td>
						</tr>
						<tr>
							<th>国</th>
							<td>
								<select id="country" name="country" class="w100p">
									<option value="">--- すべて ---</option>
									<?php $this -> echoCountry(); ?>
								</select>
							</td>
						</tr>
						<tr>
							<th>都道府県</th>
							<td><input type="text" id="state" name="state" value="<?php $this -> echoState(); ?>" class="w100p"></td>
						</tr>
<!-- 						<tr> -->
<!-- 							<th>カード</th> -->
<!-- 							<td> -->
<!-- 								<select name="card" class="w100p"> -->
<!-- 									<option value="">--- すべて ---</option> -->
<!-- 									<option value="">Option 01</option> -->
<!-- 									<option value="">Option 02</option> -->
<!-- 								</select> -->
<!-- 							</td> -->
<!-- 						</tr> -->
						<tr>
							<th>エージェントコードー</th>
							<td><input type="text" id="agent_code" name="agent_code" value="<?php $this -> echoAgentCode(); ?>" class="w100p"></td>
						</tr>
						<tr>
							<th>CRM ID</th>
							<td><input type="text" id="crm_id" name="crm_id" value="<?php $this -> echoCrmId(); ?>" class="w100p"></td>
						</tr>
						<tr>
							<th>審査状況</th>
							<td>
								<select id="kyc_flg" name="kyc_flg" class="w100p">
									<option value="all">--- すべて ---</option>
									<?php $this -> echoKYCFlg(); ?>
								</select>
							</td>
						</tr>
						<tr>
							<td colspan="2">
								<span class="th">状態</span>
								<?php $this -> dispStatuses(); ?>
							</td>
						</tr>
						<tr>
							<td colspan="2">
								<span class="th">残高</span>
								<select id="currency" name="currency" class="px60">
									<option value="">すべて</option>
									<?php $this -> dispCurrency(); ?>
								</select>
								<input type="text" id="s_min_amount" name="s_min_amount" value="<?php $this -> echoSMinAmount(); ?>" class="px80"> - <input type="text" id="s_max_amount" name="s_max_amount" value="<?php $this -> echoSMaxAmount(); ?>" class="px80">
							</td>
						</tr>
						<tr>
							<td colspan="2">
								<span class="th">口座開設日</span>
								<?php $this -> dispOpenFlg(); ?>
								<input type="text" id="from" name="from" value="<?php $this -> echoSFrom(); ?>" class="px110"> - <input type="text" id="to" name="to" value="<?php $this -> echoSTo(); ?>" class="px110">
							</td>
						</tr>
						<tr>
							<td colspan="2">
								<span class="th">最終ログイン</span>
								<?php $this -> dispLoginFlg(); ?>
								<input type="text" id="login_from" name="login_from" value="<?php $this -> echoSLoginFrom(); ?>" class="px110"> - <input type="text" id="login_to" name="login_to" value="<?php $this -> echoSLoginTo(); ?>" class="px110">
							</td>
						</tr>
						<tr>
							<td colspan="2">
								<span class="th">口座閉鎖日</span>
								<?php $this -> dispCloseFlg(); ?>
								<input type="text" id="close_from" name="close_from" value="<?php $this -> echoSCloseFrom(); ?>" class="px110"> - <input type="text" id="close_to" name="close_to" value="<?php $this -> echoSCloseTo(); ?>" class="px110">
							</td>
						</tr>
						<tr>
							<td colspan="2">
								<span class="th">口座休止日</span>
								<?php $this -> dispSuspensionFlg(); ?>
								<input type="text" id="suspension_from" name="suspension_from" value="<?php $this -> echoSSuspensionFrom(); ?>" class="px110"> - <input type="text" id="suspension_to" name="suspension_to" value="<?php $this -> echoSSuspensionTo(); ?>" class="px110">
							</td>
						</tr>
					</table>
					<p class="calign"><input type="button" id="btnImport" value="インポート" class="btn bg-grad hi25 px100"></p>
					<input type="hidden" value="search" id="type_search" name="type" />
				</form>
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
<?php include_once('template/base_nav.php'); ?>
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
							<?php $this -> dispPager(); ?>
						</div>
						<?php $this -> echoMessage(); ?>
						<form id="acForm" action="" method="post">
							<table class="table col bdr default odd w100p fontXS calign">
								<tr>
									<th class="w7p">所属WL</th>
									<th class="w10p">メールアドレス</th>
									<th class="w10p">名前</th>
									<th class="w3p">種別</th>
									<th class="w2p">口座カテゴリー</th>
									<th class="w5p">口座番号</th>
									<th class="w5p">国</th>
									<th class="w5p">都道府県</th>
									<th class="w3p">カード</th>
									<th class="w3p">審査状況</th>
									<th class="w3p">KYC</th>
									<th class="w5p">CRM ID</th>
									<th class="w5p">エージェントコード</th>
									<th class="w7p">開設日</th>
									<th class="w7p">最終ログイン</th>
									<th class="w7p">口座閉鎖日</th>
									<th class="w7p">口座休止日</th>
									<th class="w3p">詳細</th>
								</tr>
								<?php $this -> dispAccounts(); ?>
							</table>
							<input type="hidden" value="account_edit" id="action" name="action" />
							<input type="hidden" value="" id="type" name="type" />
							<input type="hidden" id="detail_account" name="detail_account" />
						</form>
						<div class="article-bottom">
							<?php $this -> dispPager(); ?>
						</div>
					</article>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
<?php include_once('template/base_foot.php'); ?>
	</div>
	<script src="js/account_list.js"></script>
</body>
</html>
